==> Dero-0.13.0-py3-none-any.whl: dero/latex/logic/extract/extract.py <==
from typing import Iterable

def extract_objs_of_type_from_ambiguous_collection(collection, obj_types):
    collected_objs = []
    if isinstance(collection, dict):
        collected_objs += _extract_objs_of_type_from_dict(collection, obj_types)
    elif _is_collection(collection, obj_types):
        collected_objs += _extract_objs_of_type_from_normal_iterable(collection, obj_types)
    elif isinstance(collection, obj_types):
        collected_objs.append(collection)
    else:
        raise ValueError(f'could not extract objs from {collection} of type {type(collection)}')

    return collected_objs


def _extract_objs_of_type_from_dict(collection, obj_types):
    collected_objs = []
    for key, obj in collection.items():
        if _is_collection(obj, obj_types):
            collected_objs += extract_objs_of_type_from_ambiguous_collection(obj, obj_types)
        elif isinstance(obj, obj_types):
            collected_objs.append(obj)
        # else, skip the object

    return collected_objs


def _extract_objs_of_type_from_normal_iterable(collection, obj_types):
    collected_objs = []
    for obj in collection:
        if _is_collection(obj, obj_types):
            collected_objs += extract_objs_of_type_from_ambiguous_collection(obj, obj_types)
        elif isinstance(obj, obj_types):
            collected_objs.append(obj)
        # else, skip the object

    return collected_objs


def _is_collection(collection, desired_obj_types):
    if isinstance(collection, str):
        return False
    if isinstance(collection, desired_obj_types):
        return False
    return isinstance(collection, Iterable)

==> Dero-0.14.0-py3-none-any.whl: dero/latex/logic/extract/extract.py <==
from typing import Iterable

# TODO: refactor to simplify

def extract_objs_of_type_from_ambiguous_collection(collection, obj_types):
    collected_objs = []
    if isinstance(collection, dict):
        collected_objs += _extract_objs_of_type_from_dict(collection, obj_types)
    elif _is_collection(collection, obj_types):
        collected_objs += _extract_objs_of_type_from_normal_iterable(collection, obj_types)
    elif isinstance(collection, obj_types):
        collected_objs.append(collection)
    else:
        raise ValueError(f'could not extract objs from {collection} of type {type(collection)}')

    return collected_objs


def _extract_objs_of_type_from_dict(collection, obj_types):
    collected_objs = []
    for key, obj in collection.items():
        if isinstance(collection, dict):
            collected_objs += _extract_objs_of_type_from_dict(collection, obj_types)
        elif _is_collection(obj, obj_types):
            collected_objs += extract_objs_of_type_from_ambiguous_collection(obj, obj_types)
        elif isinstance(obj, obj_types):
            collected_objs.append(obj)
        # else, skip the object

    return collected_objs


def _extract_objs_of_type_from_normal_iterable(collection, obj_types):
    collected_objs = []
    for obj in collection:
        if isinstance(collection, dict):
            collected_objs += _extract_objs_of_type_from_dict(collection, obj_types)
        elif _is_collection(obj, obj_types):
            collected_objs += extract_objs_of_type_from_ambiguous_collection(obj, obj_types)
        elif isinstance(obj, obj_types):
            collected_objs.append(obj)
        # else, skip the object

    return collected_objs


def _is_collection(collection, desired_obj_types):
    if isinstance(collection, str):
        return False
    if isinstance(collection, desired_obj_types):
        return False
    return isinstance(collection, Iterable)
